@@ -93,43 +93,43 @@
 #'   for computation of the Moving-Average Type-Token Ratio (Covington & McFall, 2010)
 #' @param MSTTR_segment a numeric value defining the size of the each segment
 #'   for the computation of the the Mean Segmental Type-Token Ratio (Johnson, 1944)
-#' @param ... for passing arguments to other methods
+#' @param ... not used directly
 #' @author Kenneth Benoit and Jiong Wei Lua. Many of the formulas have been
 #'   reimplemented from functions written by Meik Michalke in the \pkg{koRpus}
 #'   package.
 #' @references
-#'   Covington, M.A. & McFall, J.D. (2010). [Cutting the Gordian Knot: The
-#'   Moving-Average Type-Token Ratio
-#'   (MATTR)](https://doi.org/10.1080/09296171003643098). *Journal of
-#'   Quantitative Linguistics*, 17(2), 94--100.
+#'   Covington, M.A. & McFall, J.D. (2010). Cutting the Gordian Knot: The
+#'   Moving-Average Type-Token Ratio (MATTR) *Journal of Quantitative
+#'   Linguistics*, 17(2), 94--100.
+#'   \doi{10.1080/09296171003643098}
 #'
 #'   Herdan, G. (1955). [A New Derivation and Interpretation of Yule's
-#'   'Characteristic' *K*](https://link.springer.com/article/10.1007/BF01587632). *Zeitschrift für
-#'   angewandte Mathematik und Physik*, 6(4): 332--334.
+#'   'Characteristic'
+#'   *K*](https://link.springer.com/article/10.1007/BF01587632). *Zeitschrift
+#'   für angewandte Mathematik und Physik*, 6(4): 332--334.
 #'
 #'   Maas, H.D. (1972). Über den Zusammenhang zwischen Wortschatzumfang und
 #'   Länge eines Textes. *Zeitschrift für Literaturwissenschaft und Linguistik*,
 #'   2(8), 73--96.
 #'
-#'   McCarthy, P.M. &  Jarvis, S. (2007). [vocd: A Theoretical and Empirical
-#'   Evaluation](https://doi.org/10.1177/0265532207080767). *Language Testing*,
-#'   24(4), 459--488.
+#'   McCarthy, P.M. &  Jarvis, S. (2007). vocd: A Theoretical and Empirical
+#'   Evaluation. *Language Testing*, 24(4), 459--488.
+#'   \doi{10.1177/0265532207080767}
 #'
 #'   McCarthy, P.M. & Jarvis, S. (2010). [MTLD, vocd-D, and HD-D: A Validation
 #'   Study of Sophisticated Approaches to Lexical Diversity
-#'   Assessment](https://link.springer.com/article/10.3758/BRM.42.2.381). *Behaviour Research
-#'   Methods*, 42(2), 381--392.
+#'   Assessment](https://link.springer.com/article/10.3758/BRM.42.2.381).
+#'   *Behaviour Research Methods*, 42(2), 381--392.
 #'
-#'   Michalke, M. (2014). *koRpus: An R Package for Text Analysis (Version 0.05-4)*.
-#'   Available from <https://reaktanz.de/?c=hacking&s=koRpus>.
+#'   Michalke, M. (2014). *koRpus: An R Package for Text Analysis (Version
+#'   0.05-4)*. Available from <https://reaktanz.de/?c=hacking&s=koRpus>.
 #'
-#'   Simpson, E.H. (1949). [Measurement of
-#'   Diversity](https://doi.org/10.1038/163688a0). *Nature*, 163: 688.
+#'   Simpson, E.H. (1949). Measurement of Diversity. *Nature*, 163: 688.
+#'   \doi{10.1038/163688a0}
 #'
-#'   Tweedie. F.J. and Baayen, R.H. (1998). [How Variable May a Constant Be?
-#'   Measures of Lexical Richness in
-#'   Perspective](https://doi.org/10.1023/A:1001749303137). *Computers and the
-#'   Humanities*, 32(5), 323--352.
+#'   Tweedie. F.J. and Baayen, R.H. (1998). How Variable May a Constant Be?
+#'   Measures of Lexical Richness in Perspective. *Computers and the
+#'   Humanities*, 32(5), 323--352.  \doi{10.1023/A:1001749303137}
 #'
 #'   Yule, G. U. (1944)  *The Statistical Study of Literary Vocabulary.*
 #'   Cambridge: Cambridge University Press.
@@ -162,6 +162,9 @@ textstat_lexdiv <- function(x,
                             MATTR_window = 100L,
                             MSTTR_segment = 100L,
                             ...) {
+    measure <- match.arg(measure, c("TTR", "C", "R", "CTTR", "U", "S", "K", "I", "D",
+                                    "Vm", "Maas", "MATTR", "MSTTR", "all"),
+                         several.ok = TRUE)
     UseMethod("textstat_lexdiv")
 }
 
@@ -180,7 +183,7 @@ textstat_lexdiv.dfm <- function(x,
                                 log.base = 10,
                                 ...) {
 
-    unused_dots(...)
+    # check_dots(...)
     tokens_only_measures <-  c("MATTR", "MSTTR")
 
     x <- as.dfm(x)
@@ -232,7 +235,7 @@ textstat_lexdiv.tokens <-
              MSTTR_segment = 100L,
              ...) {
 
-    unused_dots(...)
+    check_dots(...)
     tokens_only_measures <-  c("MATTR", "MSTTR")
 
     # additional token handling
@@ -268,7 +271,6 @@ textstat_lexdiv.tokens <-
     }
 
     return(result)
-
 }
 
 # internal functions to handle lexdiv statistics for dfm and tokens -------
@@ -292,33 +294,34 @@ NULL
 #'   measures using logs)
 #' @details `compute_lexdiv_dfm_stats` in an internal function that
 #'   computes the lexical diversity measures from a [dfm] input.
-#' @importFrom data.table :=
 #' @importFrom quanteda ntoken ntype docnames
 compute_lexdiv_dfm_stats <- function(x, measure = NULL, log.base = 10) {
 
-    n_tokens <- n_types <- TTR <- C <- R <- CTTR <- U <- S <- Maas <-
-        lgV0 <- lgeV0 <- K <- D <- Vm <- I <- NULL
-    temp <- data.table(n_tokens = ntoken(x), n_types = ntype(x))
+    n_tokens <- ntoken(x)
+    n_types <- ntype(x)
+
+    result <- data.frame(document = docnames(x), n_tokens, n_types,
+                         stringsAsFactors = FALSE, row.names = NULL)
 
     if ("TTR" %in% measure)
-        temp[, TTR := n_types / n_tokens]
+        result[["TTR"]] <- n_types / n_tokens
 
     if ("C" %in% measure)
-        temp[, C := log(n_types, base = log.base) / log(n_tokens, base = log.base)]
+        result[["C"]] <- log(n_types, base = log.base) / log(n_tokens, base = log.base)
 
     if ("R" %in% measure)
-        temp[, R := n_types / sqrt(n_tokens)]
+        result[["R"]] <- n_types / sqrt(n_tokens)
 
     if ("CTTR" %in% measure)
-        temp[, CTTR := n_types / sqrt(2 * n_tokens)]
+        result[["CTTR"]] <- n_types / sqrt(2 * n_tokens)
 
     if ("U" %in% measure)
-        temp[, U := log(n_tokens, base = log.base) ^ 2 /
-                    (log(n_tokens, base = log.base) - log(n_types, base = log.base))]
+        result[["U"]] <- log(n_tokens, base = log.base) ^ 2 /
+                    (log(n_tokens, base = log.base) - log(n_types, base = log.base))
 
     if ("S" %in% measure)
-        temp[, S := log(log(n_types, base = log.base), base = log.base) /
-                    log(log(n_tokens, base = log.base), base = log.base)]
+        result[["S"]] <- log(log(n_types, base = log.base), base = log.base) /
+                    log(log(n_tokens, base = log.base), base = log.base)
 
     # computations for K, D, Vm, I
     # produces a list of data.frames that will be used for computing the measures
@@ -334,41 +337,38 @@ compute_lexdiv_dfm_stats <- function(x, measure = NULL, log.base = 10) {
     }
 
     if ("K" %in% measure)
-        temp[, K := 10 ^ 4 * vapply(ViN, function(y) sum(y$ViN * (y$i / y$n_tokens) ^ 2), numeric(1))]
+        result[["K"]] <- 10 ^ 4 * vapply(ViN, function(y) sum(y$ViN * (y$i / y$n_tokens) ^ 2), numeric(1))
     if ("I" %in% measure) {
         M_2 <- vapply(ViN, function(y) sum(y$ViN * y$i^2), numeric(1))
-        M_1 <- temp$n_types
+        M_1 <- n_types
         yule_i <- (M_1 ^ 2) / (M_2 - M_1)
         yule_i[is.infinite(yule_i)] <- 0
-        temp[, I := yule_i]
+        result[["I"]] <- yule_i
     }
 
     if ("D" %in% measure)
-        temp[, D := vapply(ViN,
+        result[["D"]] <- vapply(ViN,
                            function(y) sum(y$ViN * (y$i / y$n_tokens) * ((y$i - 1) / (y$n_tokens - 1))),
-                           numeric(1))]
+                           numeric(1))
 
     if ("Vm" %in% measure)
-        temp[, Vm := vapply(ViN,
+        result[["Vm"]] <- vapply(ViN,
                             function(y) sqrt(sum(y$ViN * (y$i / y$n_tokens) ^ 2) - 1 / y$n_types[1]),
-                            numeric(1))]
+                            numeric(1))
 
     if ("Maas" %in% measure) {
         measure <- c(measure, "lgV0", "lgeV0")
-        temp[, Maas := sqrt((log(n_tokens, base = log.base) - log(n_types, base = log.base)) /
-                             log(n_tokens, base = log.base) ^ 2)]
-        temp[, lgV0 := log10(n_types) / sqrt(1 - (log10(n_types) / (log10(n_tokens) + 0)) ^ 2)]
-        temp[, lgeV0 := log(n_types) / sqrt(1 - (log(n_types) / (log(n_tokens) + 0)) ^ 2)]
+        result[["Maas"]] <- sqrt((log(n_tokens, base = log.base) - log(n_types, base = log.base)) /
+                             log(n_tokens, base = log.base) ^ 2)
+        result[["lgV0"]] <- log10(n_types) / sqrt(1 - (log10(n_types) / (log10(n_tokens) + 0)) ^ 2)
+        result[["lgeV0"]] <- log(n_types) / sqrt(1 - (log(n_types) / (log(n_tokens) + 0)) ^ 2)
     }
 
     # return missings for tokens-only measures
-    MATTR <- MSTTR <- NULL
-    if ("MATTR" %in% measure) temp[, MATTR := NA]
-    if ("MSTTR" %in% measure) temp[, MSTTR := NA]
+    if ("MATTR" %in% measure) result[["MATTR"]] <- NA
+    if ("MSTTR" %in% measure) result[["MSTTR"]] <- NA
 
-    result <- data.frame(document = docnames(x), stringsAsFactors = FALSE)
-    if (length(measure))
-        result <- cbind(result, as.data.frame(temp[, measure, with = FALSE]))
+    if (length(measure)) result <- result[, c("document", measure)]
     result[is.na(result)] <- NA
     class(result) <- c("lexdiv", "textstat", "data.frame")
     return(result)
@@ -467,12 +467,13 @@ compute_msttr <- function(x, MSTTR_segment) {
 #' @param x input [dfm]
 #' @keywords internal dfm
 #' @importFrom quanteda featnames tokens dfm_compress
+#' @importFrom stringi stri_detect_regex
 dfm_split_hyphenated_features <- function(x) {
     # the global for matching the hyphens and similar characters
     hyphen_regex <- "^.+\\p{Pd}.+$"
 
     # figure out where the hyphens are
-    hyphenated_index <- which(stringi::stri_detect_regex(featnames(x), hyphen_regex))
+    hyphenated_index <- which(stri_detect_regex(featnames(x), hyphen_regex))
 
     # return dfm unmodified if no hyphenated features are found
     if (length(hyphenated_index) == 0) return(x)
