@@ -488,7 +488,7 @@ textstat_readability.corpus <- function(x,
                                         max_sentence_length = 10000,
                                         intermediate = FALSE, ...) {
 
-    unused_dots(...)
+    check_dots(...)
 
     measure_option <- c("ARI", "ARI.simple", "ARI.NRI",
                         "Bormuth", "Bormuth.MC", "Bormuth.GP",
@@ -550,260 +550,240 @@ textstat_readability.corpus <- function(x,
     n_syll <- lapply(n_syll, function(y) ifelse(is.na(y), 1, y))
 
     # lengths in characters of the words
-    len_token <- lapply(toks, stringi::stri_length)
-
-    # to avoid "no visible binding for global variable" CHECK NOTE
-    textID <- W <- St <- C <- Sy <- W3Sy <- W2Sy <- W_1Sy <- W6C <- W7C <- Wlt3Sy <- W_wl.Dale.Chall <-
-        W_wl.Spache <- ARI <- ARI.NRI <- ARI.simple <- Bormuth.MC <- Bormuth.GP <- Coleman <- Coleman.C2 <-
-        Coleman.Liau.ECP <- Coleman.Liau.grade <- Coleman.Liau.short <- Dale.Chall <- Dale.Chall.old <-
-        Dale.Chall.PSK <- Danielson.Bryan <- Danielson.Bryan.2 <- Dickes.Steiwer <- DRP <- ELF <-
-        Farr.Jenkins.Paterson <- Flesch <- Flesch.PSK <- Flesch.Kincaid <- FOG <- FOG.PSK <- FOG.NRI <-
-        FORCAST <- FORCAST.RGL <- Fucks <- Linsear.Write <- LIW <- nWS <- nWS.2 <- nWS.3 <- nWS.4 <-
-        RIX <- SMOG <- SMOG.C <- SMOG.simple <- SMOG.de <- Spache <- Spache.old <- Strain <- Wheeler.Smith <-
-        Bl <- Traenkle.Bailer <- Traenkle.Bailer.2 <- Bormuth <- Bormuth.MC.Temp <- Coleman.Liau.ECP.Temp <-
-        Coleman.Liau <- meanSentenceLength <- meanWordSyllables <- NULL
+    len_token <- lapply(toks, stri_length)
 
     # common statistics required by (nearly all) indexes
-    temp <- data.table(textID = names(x),
-                       W = lengths(toks),  # number of words
-                       St = n_sent,            # number of sentences
-                       C =  vapply(len_token, sum, numeric(1)), # number of characters (letters)
-                       Sy = vapply(n_syll, sum, numeric(1)),    # number of syllables
-                       W3Sy =  vapply(n_syll, function(x) sum(x >= 3), numeric(1)),  # number words with >= 3 syllables
-                       W2Sy =  vapply(n_syll, function(x) sum(x >= 2), numeric(1)),  # number words with >= 2 syllables
-                       W_1Sy = vapply(n_syll, function(x) sum(x == 1), numeric(1)),  # number words with 1 syllable
-                       W6C = vapply(len_token, function(x) sum(x >= 6), numeric(1)), # number of words with at least 6 letters
-                       W7C = vapply(len_token, function(x) sum(x >= 7), numeric(1))) # number of words with at least 7 letters
+    W <- lengths(toks)  # number of words
+    St <- n_sent        # number of sentences
+    C <-  vapply(len_token, sum, numeric(1))                      # number of characters (letters)
+    Sy <- vapply(n_syll, sum, numeric(1))                         # number of syllables
+    W3Sy <- vapply(n_syll, function(x) sum(x >= 3), numeric(1))   # number words with >= 3 syllables
+    W2Sy <- vapply(n_syll, function(x) sum(x >= 2), numeric(1))   # number words with >= 2 syllables
+    W_1Sy <- vapply(n_syll, function(x) sum(x == 1), numeric(1))  # number words with 1 syllable
+    W6C <- vapply(len_token, function(x) sum(x >= 6), numeric(1)) # number of words with at least 6 letters
+    W7C <- vapply(len_token, function(x) sum(x >= 7), numeric(1)) # number of words with at least 7 letters
+    Wlt3Sy <- W - W3Sy  # number of words with less than three syllables
 
-    temp[, Wlt3Sy := W - W3Sy]   # number of words with less than three syllables
+    result <- data.frame(document = names(x), row.names = NULL)
 
     # look up D-C words if needed
     if (any(c("Dale.Chall", "Dale.Chall.old", "Dale.Chall.PSK", "Bormuth.MC", "Bormuth.GP", "DRP") %in% measure)) {
-        temp[, W_wl.Dale.Chall := lengths(tokens_remove(toks,
-                                                        pattern = quanteda.textstats::data_char_wordlists$dalechall,
-                                                        valuetype = "fixed",
-                                                        case_insensitive = TRUE))]
+        W_wl.Dale.Chall <- lengths(tokens_remove(toks,
+                                                 pattern = quanteda.textstats::data_char_wordlists$dalechall,
+                                                 valuetype = "fixed",
+                                                 case_insensitive = TRUE))
     }
 
     if ("ARI" %in% measure)
-        temp[, ARI := 0.5 * W / St + 4.71 * C / W - 21.43]
+        result[["ARI"]] <- 0.5 * W / St + 4.71 * C / W - 21.43
 
     if ("ARI.NRI" %in% measure)
-        temp[, ARI.NRI := 0.4 * W / St + 6 * C / W - 27.4]
+        result[["ARI.NRI"]] <- 0.4 * W / St + 6 * C / W - 27.4
 
     if ("ARI.simple" %in% measure)
-        temp[, ARI.simple := W / St + 9 * C / W]
+        result[["ARI.simple"]] <- W / St + 9 * C / W
 
     if ("Bormuth.MC" %in% measure) {
-        temp[, Bormuth.MC := 0.886593 - (0.08364 * C / W) + 0.161911 * (W_wl.Dale.Chall / W) ^ 3 -
-                 0.21401 * (W / St) + 0.000577 * (W / St) ^ 2 - 0.000005 * (W / St) ^ 3]
+        result[["Bormuth.MC"]] <- 0.886593 - (0.08364 * C / W) + 0.161911 * (W_wl.Dale.Chall / W) ^ 3 -
+            0.21401 * (W / St) + 0.000577 * (W / St) ^ 2 - 0.000005 * (W / St) ^ 3
     }
     if ("Bormuth.GP" %in% measure) {
         CCS <- 35 # Cloze criterion score, percent as integer
-        temp[, Bormuth.MC.Temp := 0.886593 - (0.08364 * C / W) + 0.161911 *
+        Bormuth.MC.Temp <- 0.886593 - (0.08364 * C / W) + 0.161911 *
                  (W_wl.Dale.Chall / W) ^ 3 - 0.21401 * (W / St) + 0.000577 *
-                 (W / St) ^ 2 - 0.000005 * (W / St) ^ 3]
-        temp[, Bormuth.GP := 4.275 +
+                 (W / St) ^ 2 - 0.000005 * (W / St) ^ 3
+        result[["Bormuth.GP"]] <- 4.275 +
                  12.881 * Bormuth.MC.Temp -
                  (34.934 * Bormuth.MC.Temp^2) +
                  (20.388 * Bormuth.MC.Temp^3) +
                  (26.194 * C - 2.046 * CCS ^ 2) - (11.767 * CCS ^ 3) -
                  (44.285 * Bormuth.MC.Temp * CCS) +
                  (97.620 * (Bormuth.MC.Temp * CCS)^2) -
-                 (59.538 * (Bormuth.MC.Temp * CCS)^3)]
-        temp[, Bormuth.MC.Temp := NULL]
+                 (59.538 * (Bormuth.MC.Temp * CCS)^3)
     }
 
     if ("Coleman" %in% measure)
-        temp[, Coleman := 1.29 * (100 * W_1Sy / W) - 38.45]
+        result[["Coleman"]] <- 1.29 * (100 * W_1Sy / W) - 38.45
 
     if ("Coleman.C2" %in% measure)
-        temp[, Coleman.C2 := 1.16 * (100 * W_1Sy / W) + 1.48 * (100 * St / W) - 37.95]
+        result[["Coleman.C2"]] <- 1.16 * (100 * W_1Sy / W) + 1.48 * (100 * St / W) - 37.95
 
     ## cannot compute Coleman.C3, Coleman.C4 without knowing the number of pronouns or prepositions
 
     if ("Coleman.Liau.ECP" %in% measure)
-        temp[, Coleman.Liau.ECP   := 141.8401 - 0.214590 * (100 * C / W) + 1.079812 * (100 * St / W)]
+        result[["Coleman.Liau.ECP"]] <- 141.8401 - 0.214590 * (100 * C / W) + 1.079812 * (100 * St / W)
 
     if ("Coleman.Liau.grade" %in% measure) {
-        temp[, Coleman.Liau.ECP.Temp   := 141.8401 - 0.214590 * (100 * C / W) + 1.079812 * (100 * St / W)]
-        temp[, Coleman.Liau.grade := -27.4004 * Coleman.Liau.ECP.Temp / 100 + 23.06395]
-        temp[, Coleman.Liau.ECP.Temp   := NULL]
+        Coleman.Liau.ECP.Temp <- 141.8401 - 0.214590 * (100 * C / W) + 1.079812 * (100 * St / W)
+        result[["Coleman.Liau.grade"]] <- -27.4004 * Coleman.Liau.ECP.Temp / 100 + 23.06395
     }
 
     if ("Coleman.Liau.short" %in% measure)
-        temp[, Coleman.Liau.short := 5.88 * C / W - 29.6 * St / W - 15.8]
+        result[["Coleman.Liau.short"]] <- 5.88 * C / W - 29.6 * St / W - 15.8
 
     if ("Dale.Chall" %in% measure) {
-        temp[, Dale.Chall := 64 - 0.95 * 100 * W_wl.Dale.Chall / W - 0.69 * W / St]
+        result[["Dale.Chall"]] <- 64 - 0.95 * 100 * W_wl.Dale.Chall / W - 0.69 * W / St
     }
 
     if ("Dale.Chall.old" %in% measure) {
         DC_constant <- NULL
-        temp[, DC_constant := ((W_wl.Dale.Chall / W) > .05) * 3.6365]
-        temp[, Dale.Chall.old := 0.1579 * 100 * W_wl.Dale.Chall / W + 0.0496 * W / St + DC_constant]
-        temp[, DC_constant := NULL]
+        DC_constant <- ((W_wl.Dale.Chall / W) > .05) * 3.6365
+        result[["Dale.Chall.old"]] <- 0.1579 * 100 * W_wl.Dale.Chall / W + 0.0496 * W / St + DC_constant
     }
 
     # Powers-Sumner-Kearl (1958) variation
     if ("Dale.Chall.PSK" %in% measure)
-        temp[, Dale.Chall.PSK := 0.1155 * 100 * W_wl.Dale.Chall / W + 0.0596 * W / St + 3.2672]
+        result[["Dale.Chall.PSK"]] <- 0.1155 * 100 * W_wl.Dale.Chall / W + 0.0596 * W / St + 3.2672
 
     if ("Danielson.Bryan" %in% measure) {
-        temp[, Bl := W - 1]  # could be more accurate if count spaces
-        temp[, Danielson.Bryan := (1.0364 * C / Bl) + (0.0194 * C / St) - 0.6059]
-        temp[, Bl := NULL]
+        Bl <- W - 1  # could be more accurate if count spaces
+        result[["Danielson.Bryan"]] <- (1.0364 * C / Bl) + (0.0194 * C / St) - 0.6059
     }
 
     if ("Danielson.Bryan.2" %in% measure) {
-        temp[, Bl := W - 1]  # could be more accurate if count spaces
-        temp[, Danielson.Bryan.2 := 131.059 - (10.364 * C / Bl) + (0.0194 * C / St)]
-        temp[, Bl := NULL]
+        Bl <- W - 1  # could be more accurate if count spaces
+        result[["Danielson.Bryan.2"]] <- 131.059 - (10.364 * C / Bl) + (0.0194 * C / St)
     }
 
     if ("Dickes.Steiwer" %in% measure) {
         TTR <- textstat_lexdiv(dfm(x, verbose = FALSE), measure = "TTR")$TTR
-        temp[, Dickes.Steiwer := 235.95993 - (73.021 * C / W) - (12.56438 * W / St) - (50.03293 * TTR)]
+        result[["Dickes.Steiwer"]] <- 235.95993 - (73.021 * C / W) - (12.56438 * W / St) - (50.03293 * TTR)
     }
 
     if ("DRP" %in% measure) {
-        temp[, Bormuth.MC.Temp := 0.886593 - (0.08364 * C / W) +
+        Bormuth.MC.Temp <- 0.886593 - (0.08364 * C / W) +
                  0.161911 * (W_wl.Dale.Chall / W) ^ 3 -
                  0.21401 * (W / St) +
-                 0.000577 * (W / St) ^ 2 - 0.000005 * (W / St) ^ 3]
-        temp[, DRP := (1 - Bormuth.MC.Temp) * 100]
-        temp[, Bormuth.MC.Temp := NULL]
+                 0.000577 * (W / St) ^ 2 - 0.000005 * (W / St) ^ 3
+        result[["DRP"]] <- (1 - Bormuth.MC.Temp) * 100
     }
 
     if ("ELF" %in% measure)
-        temp[, ELF := W2Sy / St]
+        result[["ELF"]] <- W2Sy / St
 
     if ("Farr.Jenkins.Paterson" %in% measure)
-        temp[, Farr.Jenkins.Paterson := -31.517 - 1.015 * W / St + 1.599 * W_1Sy / W]
+        result[["Farr.Jenkins.Paterson"]] <- -31.517 - 1.015 * W / St + 1.599 * W_1Sy / W
 
     if ("Flesch" %in% measure)
-        temp[, Flesch := 206.835 - 1.015 * W / St - 84.6 * Sy / W]
+        result[["Flesch"]] <- 206.835 - 1.015 * W / St - 84.6 * Sy / W
 
     if ("Flesch.PSK" %in% measure)
-        temp[, Flesch.PSK := 0.0778 * W / St + 4.55 * Sy / W - 2.2029]
+        result[["Flesch.PSK"]] <- 0.0778 * W / St + 4.55 * Sy / W - 2.2029
 
     if ("Flesch.Kincaid" %in% measure)
-        temp[, Flesch.Kincaid := 0.39 * W / St + 11.8 * Sy / W - 15.59]
+        result[["Flesch.Kincaid"]] <- 0.39 * W / St + 11.8 * Sy / W - 15.59
 
     if ("meanSentenceLength" %in% measure)
-        temp[, meanSentenceLength := W / St]
+        result[["meanSentenceLength"]] <- W / St
 
     if ("meanWordSyllables" %in% measure)
-        temp[, meanWordSyllables := Sy / W]
+        result[["meanWordSyllables"]] <- Sy / W
 
     if ("FOG" %in% measure)
-        temp[, FOG := 0.4 * (W / St + 100 * W3Sy / W)]
+        result[["FOG"]] <- 0.4 * (W / St + 100 * W3Sy / W)
     # If the text was POS-tagged accordingly, proper nouns and combinations of only easy words
     # will not be counted as hard words, and the syllables of verbs ending in "-ed", "-es" or
     # "-ing" will be counted without these suffixes.
 
     if ("FOG.PSK" %in% measure)
-        temp[, FOG.PSK := 3.0680 * ( 0.0877 * W / St ) + (0.0984 * 100 * W3Sy / W )]
+        result[["FOG.PSK"]] <- 3.0680 * ( 0.0877 * W / St ) + (0.0984 * 100 * W3Sy / W )
 
     if ("FOG.NRI" %in% measure)
-        temp[, FOG.NRI := ((( Wlt3Sy + 3 * W3Sy ) / (100 * St / W)) - 3) / 2]
+        result[["FOG.NRI"]] <- ((( Wlt3Sy + 3 * W3Sy ) / (100 * St / W)) - 3) / 2
 
     if ("FORCAST" %in% measure)
-        temp[, FORCAST := 20 - (W_1Sy * 150 / W) / 10]
+        result[["FORCAST"]] <- 20 - (W_1Sy * 150 / W) / 10
 
     if ("FORCAST.RGL" %in% measure)
-        temp[, FORCAST.RGL := 20.43 - 0.11 * W_1Sy * 150 / W]
+        result[["FORCAST.RGL"]] <- 20.43 - 0.11 * W_1Sy * 150 / W
 
     if ("Fucks" %in% measure)
-        temp[, Fucks := C / W * W / St]
+        result[["Fucks"]] <- C / W * W / St
 
     if ("Linsear.Write" %in% measure)
-        temp[, Linsear.Write := ((100 - (100 * Wlt3Sy) / W) + (3 * 100 * W3Sy / W)) / (100 * St / W)]
+        result[["Linsear.Write"]] <- ((100 - (100 * Wlt3Sy) / W) + (3 * 100 * W3Sy / W)) / (100 * St / W)
 
     if ("LIW" %in% measure)
-        temp[, LIW := (W / St) + (100 * W7C) / W]
+        result[["LIW"]] <- (W / St) + (100 * W7C) / W
 
     if ("nWS" %in% measure)
-        temp[, nWS := 19.35 * W3Sy / W + 0.1672 * W / St + 12.97 * W6C / W - 3.27 * W_1Sy / W - 0.875]
+        result[["nWS"]] <- 19.35 * W3Sy / W + 0.1672 * W / St + 12.97 * W6C / W - 3.27 * W_1Sy / W - 0.875
 
     if ("nWS.2" %in% measure)
-        temp[, nWS.2 := 20.07 * W3Sy / W + 0.1682 * W / St + 13.73 * W6C / W - 2.779]
+        result[["nWS.2"]] <- 20.07 * W3Sy / W + 0.1682 * W / St + 13.73 * W6C / W - 2.779
 
     if ("nWS.3" %in% measure)
-        temp[, nWS.3 := 29.63 * W3Sy / W + 0.1905 * W / St - 1.1144]
+        result[["nWS.3"]] <- 29.63 * W3Sy / W + 0.1905 * W / St - 1.1144
 
     if ("nWS.4" %in% measure)
-        temp[, nWS.4 := 27.44 * W3Sy / W + 0.2656 * W / St - 1.693]
+        result[["nWS.4"]] <- 27.44 * W3Sy / W + 0.2656 * W / St - 1.693
 
     if ("RIX" %in% measure)
-        temp[, RIX := W7C / St]
+        result[["RIX"]] <- W7C / St
 
     if ("SMOG" %in% measure)
-        temp[, SMOG := 1.043 * sqrt(W3Sy * 30 / St) + 3.1291]
+        result[["SMOG"]] <- 1.043 * sqrt(W3Sy * 30 / St) + 3.1291
 
     if ("SMOG.C" %in% measure)
-        temp[, SMOG.C := 0.9986 * sqrt(W3Sy * 30 / St + 5) + 2.8795]
+        result[["SMOG.C"]] <- 0.9986 * sqrt(W3Sy * 30 / St + 5) + 2.8795
 
     if ("SMOG.simple" %in% measure)
-        temp[, SMOG.simple := sqrt(W3Sy * 30 / St) + 3]
+        result[["SMOG.simple"]] <- sqrt(W3Sy * 30 / St) + 3
 
     if ("SMOG.de" %in% measure)
-        temp[, SMOG.de := sqrt(W3Sy * 30 / St) - 2]
+        result[["SMOG.de"]] <- sqrt(W3Sy * 30 / St) - 2
 
     if (any(c("Spache", "Spache.old") %in% measure)) {
         # number of words which are not in the Spache word list
-        temp[, W_wl.Spache := lengths(tokens_remove(toks,
-                                                    pattern = quanteda.textstats::data_char_wordlists$spache,
-                                                    valuetype = "fixed",
-                                                    case_insensitive = TRUE))]
+        W_wl.Spache <- lengths(tokens_remove(toks,
+                                             pattern = quanteda.textstats::data_char_wordlists$spache,
+                                             valuetype = "fixed",
+                                             case_insensitive = TRUE))
     }
 
     if ("Spache" %in% measure)
-        temp[, Spache := 0.121 * W / St + 0.082 * (100 * W_wl.Spache / W) + 0.659]
+        result[["Spache"]] <- 0.121 * W / St + 0.082 * (100 * W_wl.Spache / W) + 0.659
 
     if ("Spache.old" %in% measure)
-        temp[, Spache.old := 0.141 * W / St + 0.086 * (100 * W_wl.Spache / W) + 0.839]
-
-    if (any(c("Spache", "Spache.old") %in% measure)) temp[, W_wl.Spache := NULL]
+        result[["Spache.old"]] <- 0.141 * W / St + 0.086 * (100 * W_wl.Spache / W) + 0.839
 
     if ("Strain" %in% measure)
-        temp[, Strain := Sy * 1 / (St / 3) / 10]
+        result[["Strain"]] <- Sy * 1 / (St / 3) / 10
 
     if ("Traenkle.Bailer" %in% measure) {
         Wprep <- vapply(toks, function(x) sum(x %in% prepositions), numeric(1))  # English prepositions
         Wconj <- vapply(toks, function(x) sum(x %in% conjunctions), numeric(1))  # English conjunctions
-        temp[, Traenkle.Bailer := 224.6814 - (79.8304 * C / W) - (12.24032 * W / St) - (1.292857 * 100 * Wprep / W)]
+        result[["Traenkle.Bailer"]] <- 224.6814 - (79.8304 * C / W) - (12.24032 * W / St) - (1.292857 * 100 * Wprep / W)
     }
 
     if ("Traenkle.Bailer.2" %in% measure) {
         Wprep <- vapply(toks, function(x) sum(x %in% prepositions), numeric(1))  # English prepositions
         Wconj <- vapply(toks, function(x) sum(x %in% conjunctions), numeric(1))  # English conjunctions
-        temp[, Traenkle.Bailer.2 := 234.1063 - (96.11069 * C / W) - (2.05444 * 100 * Wprep / W) - (1.02805 * 100 * Wconj / W)]
+        result[["Traenkle.Bailer.2"]] <- 234.1063 - (96.11069 * C / W) - (2.05444 * 100 * Wprep / W) - (1.02805 * 100 * Wconj / W)
     }
 
     #     if ("TRI" %in% measure) {
     #         Ptn <- lengths(tokens(x, remove_punct = FALSE)) - lengths(toks)
     #         Frg <- NA  # foreign words -- cannot compute without a dictionary
-    #         temp[, TRI := (0.449 * W_1Sy) - (2.467 * Ptn) - (0.937 * Frg) - 14.417]
+    #         result[["TRI <- (0.449 * W_1Sy) - (2.467 * Ptn) - (0.937 * Frg) - 14.417]
     #     }
 
     if ("Wheeler.Smith" %in% measure)
-        temp[, Wheeler.Smith := W / St * (10 * W2Sy) / W]
+        result[["Wheeler.Smith"]] <- W / St * (10 * W2Sy) / W
 
-    Scrabble <- NULL
     if ("Scrabble" %in% measure)
-        temp[, Scrabble := nscrabble(x, mean)]
+        result[["Scrabble"]] <- nscrabble(x, mean)
 
-    result <- data.frame(document = names(x), stringsAsFactors = FALSE)
 
+    result <- result[, c("document", measure)]
 
     # if intermediate is desired, add intermediate quantities to output
-    if (intermediate)
-        measure <- c(measure, names(temp)[names(temp) %in%
-                                              c(c("W", "St", "C", "Sy", "W3Sy", "W2Sy", "W_1Sy",
-                                                  "W6C", "W7C", "Wlt3Sy", "W_wl.Dale.Chall", "W_wl.Spache"))])
-
-    result <- cbind(result, as.data.frame(temp[, measure, with = FALSE]))
+    if (intermediate) {
+        result <- cbind(result,
+                        data.frame(W, St, C, Sy, W3Sy, W2Sy, W_1Sy, W6C, W7C, Wlt3Sy))
+        if (exists("W_wl.Dale.Chall")) result <- cbind(result, W_wl.Dale.Chall)
+        if (exists("W_wl.Spache")) result <- cbind(result, W_wl.Spache)
+    }
 
     # make any NA or NaN into NA (for #1976)
     result[is.na(result)] <- NA
@@ -851,13 +831,14 @@ prepositions <- c("a", "abaft", "abeam", "aboard", "about", "above", "absent",
 #' it is a named list of character vectors where each list element
 #' corresponds to a different readability index.
 #'
-#' @details
-#' These are:
+#' @format
+#' A list of length two:
 #' \describe{
 #' \item{`DaleChall`}{The long Dale-Chall list of 3,000 familiar (English)
 #' words needed to compute the Dale-Chall Readability Formula.}
-#' \item{`Spache`}{The revised Spache word list (see Klare 1975, 73) needed
-#' to compute the Spache Revised Formula of readability (Spache 1974.}
+#' \item{`Spache`}{The revised Spache word list (see Klare 1975, 73; Spache
+#' 1974) needed to compute the Spache Revised Formula of readability (Spache
+#' 1953).}
 #' }
 #' @references
 #' Chall, J.S., & Dale, E. (1995). *Readability Revisited: The New
@@ -875,11 +856,6 @@ prepositions <- c("a", "abaft", "abeam", "aboard", "about", "above", "absent",
 #' Spache, G. (1953). A New Readability Formula for Primary-Grade Reading
 #' Materials. *The Elementary School Journal*, 53, 410--413.
 #'
-#' Tränkle, U. & Bailer, H. (1984). Kreuzvalidierung und Neuberechnung von
-#' Lesbarkeitsformeln für die deutsche Sprache. *Zeitschrift für
-#' Entwicklungspsychologie und Pädagogische Psychologie*, 16(3), 231--244.
-#'
-#' Wheeler, L.R. & Smith, E.H. (1954). A Practical Readability Formula for the
-#' Classroom Teacher in the Primary Grades. *Elementary English*, 31,
-#' 397--399.
+#' Spache, G. (1974).  _Good reading for poor readers_. (Rvd. 9th Ed.)
+#' Champaign, Illinois: Garrard, 1974.
 "data_char_wordlists"
